@@ -1,11 +1,12 @@
+import os
 import fnmatch
 import logging
-from os import PathLike
 from typing import Iterable
 from pathlib import Path
 from functools import partial
 
 import microcore as mc
+from gito.gh_api import gh_api
 from microcore import ui
 from git import Repo, Commit
 from git.exc import GitCommandError
@@ -66,16 +67,57 @@ def commit_in_branch(repo: Repo, commit: Commit, target_branch: str) -> bool:
     return False
 
 
+def get_base_branch(repo: Repo, pr: int | str = None):
+    if os.getenv('GITHUB_ACTIONS'):
+
+        # triggered from PR
+        if base_ref := os.getenv('GITHUB_BASE_REF'):
+            logging.info(f"Using GITHUB_BASE_REF:{base_ref} as base branch")
+            return f'origin/{base_ref}'
+        logging.info("GITHUB_BASE_REF is not available...")
+        if pr:
+            api = gh_api(repo=repo)
+            pr_obj = api.pulls.get(pr)
+            logging.info(
+                f"Using 'origin/{pr_obj.base.ref}' as base branch "
+                f"(received via GH API for PR#{pr})"
+            )
+            return f'origin/{pr_obj.base.ref}'
+
+    try:
+        logging.info(
+            "Trying to resolve base branch from repo.remotes.origin.refs.HEAD.reference.name..."
+        )
+        # 'origin/main', 'origin/master', etc
+        # Stopped working in github actions since 07/2025
+        return repo.remotes.origin.refs.HEAD.reference.name
+    except AttributeError:
+        try:
+            logging.info(
+                "Checking if repo has 'main' or 'master' branchs to use as --against branch..."
+            )
+            remote_refs = repo.remotes.origin.refs
+            for branch_name in ['main', 'master']:
+                if hasattr(remote_refs, branch_name):
+                    return f'origin/{branch_name}'
+        except Exception:
+            pass
+
+        logging.error("Could not determine default branch from remote refs.")
+        raise ValueError("No default branch found in the repository.")
+
+
 def get_diff(
     repo: Repo = None,
     what: str = None,
     against: str = None,
     use_merge_base: bool = True,
+    pr: str | int = None
 ) -> PatchSet | list[PatchedFile]:
     repo = repo or Repo(".")
     if not against:
         # 'origin/main', 'origin/master', etc
-        against = repo.remotes.origin.refs.HEAD.reference.name
+        against = get_base_branch(repo, pr=pr)
     if review_subject_is_index(what):
         what = None  # working copy
     if use_merge_base:
@@ -175,7 +217,7 @@ def get_diff(
         )
         if file_path == DEV_NULL:
             continue
-        if is_binary_file(repo, file_path.lstrip("b/")):
+        if is_binary_file(repo, file_path.removeprefix("b/")):
             logging.info(f"Skipping binary file: {patched_file.path}")
             continue
         non_binary_diff.append(patched_file)
@@ -251,11 +293,12 @@ def _prepare(
     against: str = None,
     filters: str | list[str] = "",
     use_merge_base: bool = True,
+    pr: str | int = None,
 ):
     repo = repo or Repo(".")
     cfg = ProjectConfig.load_for_repo(repo)
     diff = get_diff(
-        repo=repo, what=what, against=against, use_merge_base=use_merge_base
+        repo=repo, what=what, against=against, use_merge_base=use_merge_base, pr=pr,
     )
     diff = filter_diff(diff, filters)
     if not diff:
@@ -318,11 +361,17 @@ async def review(
     against: str = None,
     filters: str | list[str] = "",
     use_merge_base: bool = True,
-    out_folder: str | PathLike | None = None,
+    out_folder: str | os.PathLike | None = None,
+    pr: str | int = None
 ):
     try:
         repo, cfg, diff, lines = _prepare(
-            repo=repo, what=what, against=against, filters=filters, use_merge_base=use_merge_base
+            repo=repo,
+            what=what,
+            against=against,
+            filters=filters,
+            use_merge_base=use_merge_base,
+            pr=pr,
         )
     except NoChangesInContextError:
         logging.error("No changes to review")
@@ -378,10 +427,16 @@ def answer(
     use_merge_base: bool = True,
     use_pipeline: bool = True,
     prompt_file: str = None,
+    pr: str | int = None,
 ) -> str | None:
     try:
         repo, config, diff, lines = _prepare(
-            repo=repo, what=what, against=against, filters=filters, use_merge_base=use_merge_base
+            repo=repo,
+            what=what,
+            against=against,
+            filters=filters,
+            use_merge_base=use_merge_base,
+            pr=pr
         )
     except NoChangesInContextError:
         logging.error("No changes to review")
